@@ -548,12 +548,16 @@ sub get_root_logger {
 ##################################################
 sub additivity {
 ##################################################
-    my($self, $onoff) = @_;
+    my($self, $onoff, $no_reinit) = @_;
 
     if(defined $onoff) {
         $self->{additivity} = $onoff;
     }
 
+    if( ! $no_reinit ) {
+        $self->set_output_methods();
+    }
+
     return $self->{additivity};
 }
 
@@ -1112,6 +1116,8 @@ sub dec_level {
 
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 Log::Log4perl::Logger - Main Logger Class
